@@ -55,6 +55,7 @@ typedef struct struct_opts_1{
 	const char * back_up_file_path ;
 	const char * offset ;
 	const char * uid ;
+	const char * luks_external_header ;
 	char * const * env ;
 	char action ;
 	int partition_number ;
@@ -63,6 +64,7 @@ typedef struct struct_opts_1{
 	int mount_point_option ;
 	int print_partition_type ;
 	int share ;
+	int use_cryptsetup_for_bitlocker ;
 }struct_opts;
 
 /*
