@@ -74,21 +74,23 @@ typedef struct{
 	const char * m_point ;
 	const char * fs_opts ;
 	const char * m_opts ;
+	const char * luks_detached_header ;
+
 	size_t       key_len ;
 	uid_t        uid ;
 	int          volume_type ;
 	int          key_source ;
 	int iteration_count ;
-	int luks_detached_header ;
-	int general_detached_header ;
 	int tcrypt_keyfiles_count ;
 	int veraCrypt_volume ;
 	int trueCrypt_volume ;
 	int bitlocker_volume ;
 	int system_volume ;
+	int use_cryptsetup_for_bitlocker ;
 	const char * const * tcrypt_keyfiles ;
 	unsigned long m_flags ;
 	int use_backup_header ;
+	int use_hidden_header ;
 	void * variables ;
 }open_struct_t ;
 
@@ -123,7 +125,7 @@ typedef struct{
  * read section 8.3  of cryptsetup FAQ for more info.
  */
 
-static inline int zuluCryptWhirlpoolIsSupported()
+static inline int zuluCryptWhirlpoolIsSupported( void )
 {
 #ifdef GCRYPT_VERSION_NUMBER
 	return GCRYPT_VERSION_NUMBER >= 0x010601 && SUPPORT_WHIRLPOOL ;
@@ -217,7 +219,7 @@ int zuluCryptAttachLoopDeviceToFileUsingFileDescriptor( int fd_path,int * fd_loo
 /*
  * this function is defined in status.c
  */
-int zuluCryptTrueCryptOrVeraCryptVolume( const char * mapper ) ;
+int zuluCryptVolumeManagedByTcplay( const char * mapper ) ;
 
 /*
  * this function is defined in status.c
@@ -673,4 +675,49 @@ int zuluCryptModifyTcryptHeader( const info_t * info ) ;
  */
 int zuluCryptUserIsAMemberOfAGroup( uid_t uid,const char * groupname ) ;
 
+/*
+ * this function is defined in open_tcrypt.c
+ */
+int zuluCryptUseZuluPlayVCRYPT( void ) ;
+
+/*
+ * this function is defined in open_tcrypt.c
+ */
+int zuluCryptUseZuluPlayTCRYPT( void ) ;
+
+/*
+ * this function is defined in bitlocker.c
+ */
+int zuluCryptUseCryptsetupBitLocker( int ) ;
+
+/*
+ * this function is defined in bitlocker.c
+ */
+int zuluCryptUseDislockerBitLocker( int ) ;
+
+/*
+ * this function is defined in open_tcrypt.c
+ */
+void * zuluCryptCryptsetupTCryptVCrypt( const open_struct_t * opt ) ;
+
+/*
+ * this function is defined in bitlocker.c
+ */
+const char * zuluCryptCryptsetupBitLockerType( void ) ;
+
+/*
+ * this function is defined in open_tcrypt.c
+ */
+const char * zuluCryptCryptsetupTCRYPTType( void ) ;
+
+/*
+ * this function is defined in bitlocker.c
+ */
+int zuluCryptIsDislockerMapperPath( const char * ) ;
+
+/*
+ * this function is defined in bitlocker.c
+ */
+int zuluCryptDeviceManagedByDislocker( const char * device,uid_t ) ;
+
 #endif
