@@ -30,21 +30,96 @@
 #include "zuluplay_support.h"
 #include "check_tcrypt.h"
 
+#include "veracrypt_pim.h"
+
 static void _chown( const char * x,uid_t y,gid_t z )
 {
-	if( chown( x,y,z ) ){;}
+	if( chown( x,y,z ) ){}
 }
 static void _chmod( const char * x,mode_t y )
 {
-	if( chmod( x,y ) ){;}
+	if( chmod( x,y ) ){}
 }
 static void _write( int x,const void * y,size_t z )
 {
-	if( write( x,y,z ) ){;}
+	if( write( x,y,z ) ){}
 }
 static void _close( int x )
 {
-	if( close( x ) ){;}
+	if( close( x ) ){}
+}
+
+int zuluCryptUseZuluPlayTCRYPT()
+{
+#ifdef CRYPT_TCRYPT
+	return 0 ;
+#else
+	return 1 ;
+#endif
+}
+
+int zuluCryptUseZuluPlayVCRYPT()
+{
+#ifdef CRYPT_TCRYPT_VERA_MODES
+	return 0 ;
+#else
+	return 1 ;
+#endif
+}
+
+const char * zuluCryptCryptsetupTCRYPTType()
+{
+#ifdef CRYPT_TCRYPT
+	return CRYPT_TCRYPT ;
+#else
+	return "" ;
+#endif
+}
+
+void * zuluCryptCryptsetupTCryptVCrypt( const open_struct_t * opt )
+{
+#ifdef CRYPT_TCRYPT
+
+	struct crypt_params_tcrypt * m = malloc( sizeof( struct crypt_params_tcrypt ) ) ;
+
+	memset( m,'\0',sizeof( struct crypt_params_tcrypt ) ) ;
+
+	m->passphrase      = opt->key ;
+	m->passphrase_size = opt->key_len ;
+	m->keyfiles        = ( const char ** ) opt->tcrypt_keyfiles ;
+	m->keyfiles_count  = ( unsigned int )  opt->tcrypt_keyfiles_count ;
+
+	m->flags = CRYPT_TCRYPT_LEGACY_MODES ;
+
+	if( opt->system_volume ){
+
+		m->flags |= CRYPT_TCRYPT_SYSTEM_HEADER ;
+	}
+	if( opt->use_backup_header ){
+
+		m->flags |= CRYPT_TCRYPT_BACKUP_HEADER ;
+	}
+	if( opt->use_hidden_header ){
+
+		m->flags |= CRYPT_TCRYPT_HIDDEN_HEADER ;
+	}
+
+#if SUPPORT_VERACRYPT_PIM
+
+	m->veracrypt_pim   = ( unsigned int )  opt->iteration_count ;
+#endif
+
+#ifdef CRYPT_TCRYPT_VERA_MODES
+
+	if( opt->veraCrypt_volume ){
+
+		m->flags |= CRYPT_TCRYPT_VERA_MODES ;
+	}
+#endif
+	return m ;
+#else
+	return NULL ;
+#endif
 }
 
 string_t zuluCryptCreateKeyFile( const char * key,size_t key_len,const char * fileName )
@@ -94,7 +169,14 @@ string_t zuluCryptCreateKeyFile_1( string_t st,const char * fileName )
 	return zuluCryptCreateKeyFile( StringContent( st ),StringLength( st ),fileName ) ;
 }
 
-static int _open_tcrypt_volume( const char * device,const open_struct_t * opts )
+static int zuluExit( int st,struct crypt_device * cd, void * m )
+{
+	free( m ) ;
+	crypt_free( cd ) ;
+	return st ;
+}
+
+static int _open_tcrypt_volume_zuluplay( const char * device,const open_struct_t * opts )
 {
 	tc_api_task task ;
 	int r = !TC_OK ;
@@ -108,6 +190,15 @@ static int _open_tcrypt_volume( const char * device,const open_struct_t * opts )
 
 	string_t st = StringVoid ;
 
+	if( opts->use_hidden_header ){
+
+		/*
+		 * We return with an error here because zuluplay automatically check
+		 * for this option.
+		 */
+		return r ;
+	}
+
 	if( tc_api_initialize() ){
 
 		if( tc_api_task_initialize( &task,"map" ) ){
@@ -166,25 +257,116 @@ static int _open_tcrypt_volume( const char * device,const open_struct_t * opts )
 	return r ;
 }
 
+static int _open_tcrypt_volume_cryptsetup( const char * device,const open_struct_t * opt )
+{
+	struct crypt_device * cd ;
+	uint32_t flags ;
+	int st ;
+
+	void * m ;
+
+	if( crypt_init( &cd,device ) != 0 ){
+
+		return 2 ;
+	}
+
+	m = zuluCryptCryptsetupTCryptVCrypt( opt ) ;
+
+	if( crypt_load( cd,zuluCryptCryptsetupTCRYPTType(),m ) != 0 ){
+
+		return zuluExit( 2,cd,m ) ;
+	}
+	if( StringHasComponent( opt->m_opts,"ro" ) ){
+
+		flags = CRYPT_ACTIVATE_READONLY ;
+	}else{
+		flags = CRYPT_ACTIVATE_ALLOW_DISCARDS ;
+	}
+
+	st = crypt_activate_by_volume_key( cd,opt->mapper_name,NULL,0,flags ) ;
+
+	if( st == 0 ){
+
+		return zuluExit( 0,cd,m ) ;
+	}else{
+		return zuluExit( 1,cd,m ) ;
+	}
+}
+
+static int _open_tcrypt_volume( const char * device,const open_struct_t * opt )
+{
+	if( opt->veraCrypt_volume ){
+
+		if( zuluCryptUseZuluPlayVCRYPT() ){
+
+			return _open_tcrypt_volume_zuluplay( device,opt ) ;
+		}else{
+			return _open_tcrypt_volume_cryptsetup( device,opt ) ;
+		}
+	}else{
+		if( zuluCryptUseZuluPlayTCRYPT() ){
+
+			return _open_tcrypt_volume_zuluplay( device,opt ) ;
+		}else{
+			return _open_tcrypt_volume_cryptsetup( device,opt ) ;
+		}
+	}
+}
+
 static int _open_tcrypt_volume_1( const char * device,const resolve_path_t * opt )
 {
-	int r = _open_tcrypt_volume( device,opt->args ) ;
+	int r ;
 
 	open_struct_t opts ;
 
-	if( r == 0 ){
+	memcpy( &opts,opt->args,sizeof( opts ) ) ;
 
-		return r ;
-	}else{		
-		memcpy( &opts,opt->args,sizeof( opts ) ) ;
+	if( opts.trueCrypt_volume ){
 
-		if( opts.trueCrypt_volume ){
+		r = _open_tcrypt_volume( device,&opts ) ;
 
-			opts.use_backup_header = 1 ;
+		if( r == 0 ){
+
+			return 0 ;
+		}
+
+		opts.use_backup_header = 1 ;
+
+		r = _open_tcrypt_volume( device,&opts ) ;
+
+		if( r == 0 ){
+
+			return 0 ;
+		}
+
+		opts.use_backup_header = 0 ;
+		opts.use_hidden_header = 1 ;
+
+		r = _open_tcrypt_volume( device,&opts ) ;
+
+		if( r == 0 ){
+
+			return 0 ;
+		}
+
+		opts.use_backup_header = 0 ;
+		opts.use_hidden_header = 0 ;
+		opts.system_volume = 1 ;
+
+		return _open_tcrypt_volume( device,&opts ) ;
+	}else{
+		if( opts.system_volume || opts.use_hidden_header ){
 
 			return _open_tcrypt_volume( device,&opts ) ;
 		}else{
-			return r ;
+			if( _open_tcrypt_volume( device,&opts ) == 0 ){
+
+				return 0 ;
+			}else{
+				opts.use_hidden_header = 1 ;
+
+				return _open_tcrypt_volume( device,&opts ) ;
+			}
 		}
 	}
 }
@@ -263,48 +445,41 @@ int zuluCryptOpenTcrypt_1( const open_struct_t * opts )
 	return zuluCryptOpenVolume_0( _open_tcrypt_0,opts ) ;
 }
 
-#if CHECK_TCRYPT
-
-static int zuluExit( int st,struct crypt_device * cd )
-{
-	crypt_free( cd ) ;
-	return st ;
-}
 /*
  * 1 is returned if a volume is a truecrypt volume.
  * 0 is returned if a volume is not a truecrypt volume or functionality is not supported
  */
 int zuluCryptVolumeIsTcrypt( const char * device,const char * key,int key_source )
 {
+	void * m ;
+
+	open_struct_t s ;
+
 	struct crypt_device * cd = NULL;
-	struct crypt_params_tcrypt params ;
 
-	memset( &params,'\0',sizeof( struct crypt_params_tcrypt ) ) ;
+	memset( &s,'\0',sizeof( open_struct_t ) ) ;
 
-	if( key_source ){;}
+	if( key_source ){}
 
 	if( crypt_init( &cd,device ) < 0 ){
+
 		return 0 ;
 	}else{
-		params.passphrase      = key ;
-		params.passphrase_size = StringSize( key ) ;
-		params.flags           = CRYPT_TCRYPT_LEGACY_MODES ;
+		s.key     = key ;
+		s.key_len = StringSize( key ) ;
 
-		if( crypt_load( cd,CRYPT_TCRYPT,&params ) == 0 ){
-			return zuluExit( 1,cd ) ;
+		m = zuluCryptCryptsetupTCryptVCrypt( &s ) ;
+
+		if( m == NULL ){
+
+			return 0 ;
+		}
+
+		if( crypt_load( cd,zuluCryptCryptsetupTCRYPTType(),m ) == 0 ){
+
+			return zuluExit( 1,cd,m ) ;
 		}else{
-			return zuluExit( 0,cd ) ;
+			return zuluExit( 0,cd,m ) ;
 		}
 	}
 }
-
-#else
-
-int zuluCryptVolumeIsTcrypt( const char * device,const char * key,int key_source )
-{
-	if( 0 && device && key && key_source ){;}
-
-	return 1 ;
-}
-
-#endif
