@@ -337,13 +337,80 @@ void zuluCryptFileSystemProperties( string_t p,const char * mapper,const char *
 	StringDelete( &q ) ;
 }
 
-int zuluCryptTrueCryptOrVeraCryptVolume( const char * mapper )
+static int _string_starts_with( const char * a,const char * b )
 {
-	char buffer[ 1024 ] ;
+	return strncmp( a,b,strlen( b ) ) == 0 ;
+}
 
-	tc_api_get_volume_type( buffer,sizeof( buffer ),mapper ) ;
+static int _string_ends_with( const char * e,size_t ee,const char * s,size_t ss )
+{
+	if( ee >= ss ){
+		return memcmp( e + ee - ss,s,ss ) == 0 ;
+	}else{
+		return 0 ;
+	}
+}
 
-	return StringAtLeastOneMatch_1( buffer,"TCRYPT","VCRYPT",NULL ) ;
+static int _string_starts_and_ends_with( const char * a,const char * b,const char * c )
+{
+	if( _string_starts_with( a,b ) ){
+
+		return _string_ends_with( a,strlen( a ),c,strlen( c ) ) ;
+	}else{
+		return 0 ;
+	}
+}
+
+static int _created_with_tcplay( const char * map_name )
+{
+	DIR * dir = opendir( "/dev/disk/by-id/" ) ;
+	struct dirent * e ;
+
+	const char * m = strrchr( map_name,'/' ) ;
+
+	if( m != NULL ){
+
+		map_name = m + 1 ;
+	}
+
+	if( dir != NULL ){
+
+		while( ( e = readdir( dir ) ) != NULL ){
+
+			if ( _string_starts_and_ends_with( e->d_name,"dm-uuid-CRYPT-",map_name ) ){
+
+				if ( _string_starts_with( e->d_name,"dm-uuid-CRYPT-TCRYPT" ) ){
+
+					if ( _string_starts_with( e->d_name,"dm-uuid-CRYPT-TCRYPT-zuluCrypt" ) ){
+
+						return 0 ;
+					}else{
+						return 1 ;
+					}
+
+				}else if( _string_starts_with( e->d_name,"dm-uuid-CRYPT-VCRYPT" ) ) {
+
+					return 1 ;
+				}
+
+				break ;
+			}
+		}
+
+		closedir( dir ) ;
+	}
+
+	return 0 ;
+}
+
+int zuluCryptVolumeManagedByTcplay( const char * mapper )
+{
+	if( zuluCryptBitLockerVolume( mapper ) ){
+
+		return 0 ;
+	}else{
+		return _created_with_tcplay( mapper ) ;
+	}
 }
 
 static char * _get_type( struct crypt_device * cd,const char * mapper )
@@ -384,6 +451,10 @@ char * zuluCryptGetVolumeTypeFromMapperPath( const char * mapper )
 	struct crypt_device * cd ;
 	char * r ;
 
+	if( zuluCryptBitLockerVolume( mapper ) ){
+
+		return StringCopy_2( zuluCryptBitLockerType() ) ;
+	}
 	if( crypt_init_by_name( &cd,mapper ) < 0 ){
 
 		return StringCopy_2( "Nil" ) ;
@@ -674,7 +745,14 @@ static string_t _get_crypto_info_from_cryptsetup( const char * mapper )
 
 		if( type != NULL ){
 
-			q = String( type ) ;
+			if( StringsAreEqual( type,zuluCryptCryptsetupBitLockerType() ) ){
+
+				q = String( zuluCryptBitLockerType() ) ;
+
+				StringReplaceString( q,"crypto_","" ) ;
+			}else{
+				q = String( type ) ;
+			}
 
 			StringAppend( p,StringToLowerCase( q ) ) ;
 
@@ -774,7 +852,7 @@ char * zuluCryptVolumeStatus( const char * mapper )
 
 	string_t p ;
 
-	if( zuluCryptTrueCryptOrVeraCryptVolume( mapper ) ){
+	if( zuluCryptVolumeManagedByTcplay( mapper ) ){
 
 		p = _get_crypto_info_from_tcplay( mapper ) ;
 	}else{
@@ -825,7 +903,7 @@ char * zuluCryptVolumeDeviceName( const char * mapper )
 
 	const char * e ;
 
-	if( zuluCryptTrueCryptOrVeraCryptVolume( mapper ) ){
+	if( zuluCryptVolumeManagedByTcplay( mapper ) ){
 
 		memset( &m,'\0',sizeof( m ) ) ;
 		memset( &d,'\0',sizeof( d ) ) ;
