@@ -23,6 +23,10 @@
 
 int main( int argc,char * argv[] )
 {
+	QSettings m( "zuluCrypt","zuluCrypt" ) ;
+
+	utility::setSettingsObject( &m ) ;
+
 	utility::setHDPI( "zuluCrypt" ) ;
 
 	QApplication a( argc,argv ) ;
