@@ -63,6 +63,8 @@
 #include <QLabel>
 #include <QPushButton>
 #include <QLabel>
+#include <QDateTime>
+#include <QTime>
 
 #include <poll.h>
 #include <fcntl.h>
@@ -399,6 +401,9 @@ namespace utility
 	bool autoSetVolumeAsVeraCrypt( const QString& ) ;
 	void autoSetVolumeAsVeraCrypt( const QString&,bool ) ;
 
+	int defaultUnlockingVolumeType() ;
+	void defaultUnlockingVolumeType( int ) ;
+
 	void autoOpenFolderOnMount( const QString&,bool ) ;
 	bool autoOpenFolderOnMount( const QString& ) ;
 
@@ -438,7 +443,6 @@ namespace utility
 	bool canCreateFile( const QString& ) ;
 	bool useZuluPolkit( void ) ;
 	void startHelperExecutable( QObject *,const QString&,const QString&,const char *,const char * ) ;
-	void dropPrivileges( int = -1 ) ;
 	void setDebugWindow( debugWindow * w ) ;
 	QString fileManager( void ) ;
 	QString loopDevicePath( const QString& ) ;
@@ -539,7 +543,10 @@ namespace utility
 	QFont getFont( QWidget * ) ;
 	void saveFont( const QFont& ) ;
 
-	::Task::future< int >& clearVolume( const QString& volumePath,std::atomic_bool * exit,size_t size,std::function< void( int ) > ) ;
+	::Task::future< int >& clearVolume( const QString& volumePath,
+					    std::atomic_bool * exit,
+					    size_t size,
+					    std::function< void( quint64 size,quint64 offset ) > ) ;
 	::Task::future< int >& exec( const QString& ) ;
 	::Task::future< QStringList >& luksEmptySlots( const QString& volumePath ) ;
 	::Task::future< QString >& getUUIDFromPath( const QString& ) ;
@@ -969,40 +976,53 @@ namespace utility
 namespace utility {
 	class duration{
 	public:
-		duration( long miliseconds ) : m_milliseconds( miliseconds )
-		{
-			this->reset() ;
-		}
-		bool passed()
-		{
-			auto now = std::chrono::high_resolution_clock::now() ;
-
-			auto seconds = std::chrono::duration_cast< std::chrono::milliseconds >( now - m_start_time ).count() ;
-
-			if( seconds >= m_milliseconds ){
-
-				this->reset() ;
-
-				return true ;
-			}else{
-				return false ;
-			}
-		}
+		duration( long miliseconds ) ;
+		bool passed() ;
+		void reset() ;
 		template< typename Function >
-		void passed( Function function )
+		void passed( Function&& function )
 		{
 			if( this->passed() ){
 
 				function() ;
 			}
 		}
+		QDateTime& timer() ;
 	private:
-		void reset()
-		{
-			m_start_time = std::chrono::high_resolution_clock::now() ;
-		}
 		long m_milliseconds ;
-		decltype( std::chrono::high_resolution_clock::now() ) m_start_time ;
+		qint64 m_start_time ;
+		QDateTime m_time ;
 	};
 }
+
+namespace utility{
+class progress{
+public:
+	struct result
+	{
+		const QString& current_speed ;
+		const QString& average_speed ;
+		const QString& eta ;
+		const QString& total_time ;
+		int percentage_done ;
+	} ;
+
+	progress( int s,std::function< void( const result& ) > function ) ;
+	std::function< void( quint64 size,quint64 offset ) > updater_quint() ;
+	std::function< void( qint64 size,qint64 offset ) > updater_qint() ;
+private:
+	void update_progress( quint64 size,quint64 offset ) ;
+	QString time( double s ) ;
+	QString speed( double size,double time ) ;
+
+	int m_progress = 0 ;
+	quint64 m_offset_last ;
+	double m_total_time ;
+	std::function< void( const result& ) > m_function ;
+	utility::duration m_duration ;
+	QDateTime& m_time ;
+	double m_previousTime ;
+};
+
+}
 #endif // MISCFUNCTIONS_H
