@@ -334,7 +334,7 @@ static int _zuluMountExe( ARGS * args )
 	const char * action = args->action ;
 	const char * uuid   = args->uuid   ;
 	const char * offset = args->offset ;
-	size_t       uid    = args->uid    ;
+	uid_t        uid    = args->uid    ;
 
 	string_t st ;
 
@@ -349,11 +349,20 @@ static int _zuluMountExe( ARGS * args )
 
 		st = _zuluCryptGetFileSystemFromDevice( device ) ;
 
-		if( StringContains( st,zuluCryptBitLockerType() ) ){
+		zuluCryptSecurityGainElevatedPrivileges() ;
+
+		r = zuluCryptDeviceManagedByDislocker( device,uid ) ;
+
+		zuluCryptSecurityDropElevatedPrivileges() ;
+
+		if( StringContains( st,zuluCryptBitLockerType() ) && r ){
 
 			r = zuluMountPrintBitLockerProperties( device,uid ) ;
 
-		}else if( offset != NULL || st == StringVoid || StringStartsWith( st,"crypto_" ) ){
+		}else if( offset != NULL ||
+			  st == StringVoid ||
+			  StringsAreEqual_2( st,"Nil" ) ||
+			  StringStartsWith( st,"crypto_" ) ){
 
 			r = zuluMountVolumeStatus( device,uuid,uid ) ;
 		}else{
