@@ -78,7 +78,7 @@ zuluMount::zuluMount( QWidget * parent ) :
 
 	m_signalHandler.setAction( [ this ]( systemSignalHandler::signal s ){
 
-		Q_UNUSED( s ) ;
+		Q_UNUSED( s )
 
 		this->emergencyQuitApplication() ;
 	} ) ;
@@ -102,6 +102,7 @@ void zuluMount::helperStarted( bool start,const QString& volume )
 	m_ui->pbmenu->setMinimumHeight( 31 ) ;
 	m_ui->pbmount->setMinimumHeight( 31 ) ;
 	m_ui->pbupdate->setMinimumHeight( 31 ) ;
+	m_ui->pbfavorites->setMinimumHeight( 31 ) ;
 
 	auto f = utility::getWindowDimensions( "zuluMount" ) ;
 
@@ -153,7 +154,7 @@ void zuluMount::helperStarted( bool start,const QString& volume )
 
 	connect( m_ui->tableWidget,&QTableWidget::customContextMenuRequested,[ this ]( QPoint s ){
 
-		Q_UNUSED( s ) ;
+		Q_UNUSED( s )
 
 		auto item = m_ui->tableWidget->currentItem() ;
 
@@ -259,7 +260,7 @@ void zuluMount::helperStarted( bool start,const QString& volume )
 		return ac ;
 	}() ) ;
 
-	m_favorite_menu = [ this,trayMenu ](){
+	m_favorite_menu = [ this ](){
 
 		auto m = new QMenu( tr( "Favorites" ),this ) ;
 
@@ -439,7 +440,7 @@ void zuluMount::helperStarted( bool start,const QString& volume )
 
 void zuluMount::showTrayIcon( bool e )
 {
-	Q_UNUSED( e ) ;
+	Q_UNUSED( e )
 	m_trayIcon.show() ;
 }
 
@@ -641,7 +642,7 @@ void zuluMount::closeApplication()
 
 void zuluMount::closeApplication( int s )
 {
-	Q_UNUSED( s ) ;
+	Q_UNUSED( s )
 	m_events.stop() ;
 }
 
@@ -1552,14 +1553,18 @@ void zuluMount::unmount( const QString& e )
 	auto mountPath = m_ui->tableWidget->item( row,1 )->text() ;
 	auto type      = m_ui->tableWidget->item( row,2 )->text() ;
 
+	if( !type.startsWith( "crypto_" ) ){
+
+		utility::Task::suspendForOneSecond() ;
+	}
+
 	if( _encrypted_folder( type ) ){
 
 		if( siritask::encryptedFolderUnMount( path,mountPath,type ).await() ){
 
 			siritask::deleteMountFolder( mountPath ) ;
 		}else{
-			DialogMsg m( this ) ;
-			m.ShowUIOK( tr( "ERROR" ),tr( "Failed to unmount volume" ) ) ;
+			DialogMsg( this ).ShowUIOK( tr( "ERROR" ),tr( "Failed to unmount volume" ) ) ;
 			this->enableAll() ;
 		}
 	}else{
