@@ -21,7 +21,7 @@
 #define ZULUMOUNTTASK_H
 
 #include "volumeproperty.h"
-#include "task.h"
+#include "task.hpp"
 #include "../zuluCrypt-gui/utility.h"
 
 #include <QVector>
